@@ -248,7 +248,7 @@ class PySiteApplication(object):
 							yield res
 							raise StopIteration
 				except Exception as e:
-					logger.warning(get_traceback())
+					log.warning(get_traceback())
 					raise e
 			
 			subhandler_redirect = getattr(subhandler,'redirect',None)
@@ -257,6 +257,7 @@ class PySiteApplication(object):
 				location = subhandler_redirect(template_info,cookies,environ)
 				if location:
 					output = redirect(location,cookies,start_response)
+					raise StopIteration
 			
 			template_info['translate'] = translate
 			template = join(self.templates_dir,'%s.jinja' % template)
